/*
Copyright (C) 2022 Red Hat, Inc.

This file is part of libdnf: https://github.com/rpm-software-management/libdnf/

Libdnf is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

Libdnf is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with libdnf.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef LIBDNF5_UTILS_TO_UNDERLYING_HPP
#define LIBDNF5_UTILS_TO_UNDERLYING_HPP

#include <fmt/format.h>

#include <type_traits>

namespace libdnf5::utils {

/// Converts an enumeration to its underlying type.
/// `std::to_underlying` is planned for C++23.
template <class Enum>
constexpr std::underlying_type_t<Enum> to_underlying(Enum e) noexcept {
    return static_cast<std::underlying_type_t<Enum>>(e);
}

}  // namespace libdnf5::utils

#endif  // LIBDNF5_UTILS_TO_UNDERLYING_HPP
